summaryrefslogtreecommitdiff
path: root/src/history.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'src/history.cpp')
-rw-r--r--src/history.cpp4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/history.cpp b/src/history.cpp
index 0db73b76..07580433 100644
--- a/src/history.cpp
+++ b/src/history.cpp
@@ -114,8 +114,8 @@ void HistoryManager::addHistoryEntry(const QString &url)
{
QUrl cleanUrl(url);
- // don't store rekonq: urls (home page related)
- if(cleanUrl.scheme() == QString("rekonq"))
+ // don't store about: urls (home page related)
+ if(cleanUrl.scheme() == QString("about"))
return;
cleanUrl.setPassword(QString());